<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="vi">
<context>
    <name>App.About</name>
    <message>
        <location filename="../main.cpp" line="101"/>
        <location filename="../main.cpp" line="105"/>
        <source>System Monitor</source>
        <translation>Theo dõi hệ thống</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Theo dõi hệ thống là công cụ để theo dõi tải hệ thống thời gian thực, xem và kiểm soát các quá trình và dịch vụ đang chạy trên hệ thống của bạn.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="29"/>
        <source>Hide details</source>
        <translation>Ẩn chi tiết</translation>
    </message>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="40"/>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="52"/>
        <source>Overall utilization</source>
        <translation>Sử dụng tổng thể</translation>
    </message>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="43"/>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="54"/>
        <source>Individual utilization</source>
        <translation>Sử dụng cá nhân</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <location filename="../gui/block_dev_item_widget.cpp" line="154"/>
        <source>Read</source>
        <translation>Đọc</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_item_widget.cpp" line="158"/>
        <source>Write</source>
        <translation>Viết</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <location filename="../gui/cpu_detail_widget.cpp" line="168"/>
        <location filename="../gui/cpu_detail_widget.cpp" line="285"/>
        <source>60 seconds</source>
        <translation>60 giây</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <location filename="../model/cpu_info_model.cpp" line="49"/>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 ngày %2 giờ %3 phút</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="91"/>
        <source>Utilization</source>
        <translation>Sử dụng</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="93"/>
        <source>Frequency</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="98"/>
        <source>Max frequency</source>
        <translation>Frequency</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="100"/>
        <source>Average frequency</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="104"/>
        <source>Up time</source>
        <translation>Thời gian hoạt động</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="106"/>
        <source>Sockets</source>
        <translation>Socket</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="110"/>
        <source>Logical processors</source>
        <translation>Phát sinh xử lý</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="112"/>
        <source>Virtualization</source>
        <translation>Virtuaлизация</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="116"/>
        <source>L1i cache</source>
        <translation>L1i cache</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="118"/>
        <source>L1d cache</source>
        <translation>L1d cache</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="122"/>
        <source>L2 cache</source>
        <translation>L2 cache</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="124"/>
        <source>L3 cache</source>
        <translation>L3 cache</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="128"/>
        <source>Load average</source>
        <translation>Trung bình tải</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="130"/>
        <source>File descriptors</source>
        <translation>Mô tả tệp</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="134"/>
        <source>Processes</source>
        <translation>Quá trình</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="136"/>
        <source>Threads</source>
        <translation>Sợi</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="140"/>
        <source>Host name</source>
        <translation>Tên máy chủ</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="142"/>
        <source>OS type</source>
        <translation>Loại hệ điều hành</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="146"/>
        <source>Version</source>
        <translation>Phiên bản</translation>
    </message>
</context>
<context>
    <name>Cancel</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="310"/>
        <source>Cancel</source>
        <translation>Hủy bỏ</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <location filename="../gui/chart_view_widget.cpp" line="321"/>
        <source>60 seconds</source>
        <translation>60 giây</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="493"/>
        <location filename="../gui/system_service_table_view.cpp" line="476"/>
        <source>No search results</source>
        <translation>Không tìm thấy kết quả</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <location filename="../compact_cpu_monitor.cpp" line="89"/>
        <source>Details</source>
        <translation>Chi tiết</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <location filename="../cpu_monitor.cpp" line="72"/>
        <source>Details</source>
        <translation>Chi tiết</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="165"/>
        <source>active</source>
        <translation>hoạt động</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="167"/>
        <source>reloading</source>
        <translation>đang tải lại</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="169"/>
        <source>inactive</source>
        <translation>không hoạt động</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="170"/>
        <source>failed</source>
        <translation>thất bại</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="172"/>
        <source>activating</source>
        <translation>đang kích hoạt</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="174"/>
        <source>deactivating</source>
        <translation>đang vô hiệu hóa</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="146"/>
        <source>stub</source>
        <translation>sơ đồ</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="149"/>
        <source>not-found</source>
        <translation>không tìm thấy</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="151"/>
        <source>bad-setting</source>
        <translation>đặt cài đặt không hợp lệ</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="152"/>
        <source>error</source>
        <translation>lỗi</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="153"/>
        <source>merged</source>
        <translation>đã hợp nhất</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="154"/>
        <source>masked</source>
        <translation>đã che giấu</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="147"/>
        <source>loaded</source>
        <translation>đã tải</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="297"/>
        <source>N/A</source>
        <translation>không có dữ liệu</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="295"/>
        <source>Auto</source>
        <translation>Tự động</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="296"/>
        <source>Manual</source>
        <translation>Tay</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="274"/>
        <source>enabled</source>
        <translation>kích hoạt</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="275"/>
        <source>disabled</source>
        <translation>không kích hoạt</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="276"/>
        <source>static</source>
        <translation>định lượng</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="277"/>
        <source>transient</source>
        <translation>thông qua</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="278"/>
        <source>indirect</source>
        <translation>gián tiếp</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="280"/>
        <source>enabled-runtime</source>
        <translation>cấu hình chạy</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="281"/>
        <source>masked</source>
        <translation>ẩn</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="283"/>
        <source>generated</source>
        <translation>tự sinh</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="217"/>
        <source>dead</source>
        <translation>tử</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="219"/>
        <source>start-pre</source>
        <translation>trước khi khởi động</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="221"/>
        <source>start</source>
        <translation>khởi động</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="223"/>
        <source>start-post</source>
        <translation>sau khi khởi động</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="225"/>
        <source>running</source>
        <translation>đang chạy</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="227"/>
        <source>exited</source>
        <translation>đã thoát</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="229"/>
        <source>reload</source>
        <translation>tải lại</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="231"/>
        <source>stop</source>
        <translation>đóng</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="233"/>
        <source>stop-watchdog</source>
        <translation>đóng theo dõi</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="235"/>
        <source>stop-sigterm</source>
        <translation>đóng tín hiệu SIGTERM</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="237"/>
        <source>stop-sigkill</source>
        <translation>đóng tín hiệu SIGKILL</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="239"/>
        <source>stop-post</source>
        <translation>sau khi đóng</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="241"/>
        <source>final-sigterm</source>
        <translation>tín hiệu SIGTERM cuối cùng</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="243"/>
        <source>final-sigkill</source>
        <translation>tín hiệu SIGKILL cuối cùng</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="245"/>
        <source>failed</source>
        <translation>thất bại</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="247"/>
        <source>auto-restart</source>
        <translation>tự khởi động lại</translation>
    </message>
</context>
<context>
    <name>DBusAlarmNotify</name>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="38"/>
        <location filename="../dbus/dbusalarmnotify.cpp" line="50"/>
        <source>Warning</source>
        <translation>Cảnh báo</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="39"/>
        <source>Your CPU usage is higher than %1%!</source>
        <translation>Sử dụng CPU của bạn cao hơn %1%!
</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="51"/>
        <source>Your memory usage is higher than %1%!</source>
        <translation>Sử dụng bộ nhớ của bạn cao hơn %1%!
</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="71"/>
        <source>View</source>
        <translation>Xem</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="67"/>
        <source>Used</source>
        <translation>Đã sử dụng</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="69"/>
        <source>Available</source>
        <translation>Còn trống</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="73"/>
        <source>Shared</source>
        <translation>Chia sẻ</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="75"/>
        <source>Cached</source>
        <translation>Được lưu trữ</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="79"/>
        <source>Buffers</source>
        <translation>Buffer</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="81"/>
        <source>Cached swap</source>
        <translation>Đổi trang được lưu trữ</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="85"/>
        <source>Active</source>
        <translation>Hoạt động</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="87"/>
        <source>Inactive</source>
        <translation>Không hoạt động</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="91"/>
        <source>Dirty</source>
        <translation>Lỗi</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="93"/>
        <source>Mapped</source>
        <translation>Đã gắn</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="97"/>
        <source>Total swap</source>
        <translation>Đổi trang tổng cộng</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="99"/>
        <source>Free swap</source>
        <translation>Đổi trang trống</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="103"/>
        <source>Slab</source>
        <translation>Slab</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="70"/>
        <source>Model</source>
        <translation>Mô hình</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="72"/>
        <source>Read speed</source>
        <translation>Tốc độ đọc</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="76"/>
        <source>Write speed</source>
        <translation>Tốc độ ghi</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="78"/>
        <source>Capacity</source>
        <translation>Dung lượng</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="82"/>
        <source>Sectors read</source>
        <translation>Sector đã đọc</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="84"/>
        <source>Reads/s</source>
        <translation>Đọc/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="88"/>
        <source>Sectors read/s</source>
        <translation>Sector đọc/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="90"/>
        <source>Reads merged/s</source>
        <translation>Đọc hợp nhất/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="94"/>
        <source>Sectors written</source>
        <translation>Sector đã ghi</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="96"/>
        <source>Writes completed </source>
        <translation>Viết hoàn thành</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="100"/>
        <source>Writes merged</source>
        <translation>Viết hợp nhất</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="102"/>
        <source>Writes/s</source>
        <translation>Ghi/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="106"/>
        <source>Sectors written/s</source>
        <translation>Sectors written/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="108"/>
        <source>Writes merged/s</source>
        <translation>Writes merged/s</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <location filename="../gui/dialog/error_dialog.cpp" line="73"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <location filename="../common/common.cpp" line="32"/>
        <source>System</source>
        <translation>Hệ thống</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="38"/>
        <source>Display shortcuts</source>
        <translation>Hiển thị phím tắt</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="173"/>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Dừng quá trình này có thể gây mất dữ liệu.
Bạn có chắc chắn muốn tiếp tục không?
</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="530"/>
        <location filename="../gui/process_table_view.cpp" line="172"/>
        <location filename="../gui/process_table_view.cpp" line="379"/>
        <source>End process</source>
        <translation>Dừng quá trình</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="380"/>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Dừng mạnh quá trình này có thể gây mất dữ liệu.
Bạn có chắc chắn muốn tiếp tục không?
</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="531"/>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Dừng mạnh ứng dụng này có thể gây mất dữ liệu.
Bạn có chắc chắn muốn tiếp tục không?
</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="539"/>
        <location filename="../gui/process_table_view.cpp" line="179"/>
        <location filename="../gui/process_table_view.cpp" line="387"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Hủy bỏ</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="540"/>
        <location filename="../gui/process_table_view.cpp" line="388"/>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Dừng mạnh</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="180"/>
        <source>End</source>
        <comment>button</comment>
        <translation>Dừng</translation>
    </message>
</context>
<context>
    <name>Logout</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="311"/>
        <source>Logout</source>
        <translation>Đăng xuất</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../gui/main_window.cpp" line="181"/>
        <source>Settings</source>
        <translation>Cài đặt</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <location filename="../gui/mem_stat_view_widget.cpp" line="52"/>
        <source>Size</source>
        <translation>Kích thước</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <location filename="../gui/netif_summary_view_widget.h" line="159"/>
        <source>IP address:</source>
        <translation>IP address:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <source>Netmask:</source>
        <translation>Netmask:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <source>Broadcast:</source>
        <translation>Broadcast:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="159"/>
        <source>Prefixlen:</source>
        <translation>Prefixlen:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="159"/>
        <source>Scope:</source>
        <translation>Scope:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="293"/>
        <source>Connection type</source>
        <translation>Loại kết nối</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="301"/>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="307"/>
        <source>Link quality</source>
        <translation>Chất lượng kết nối</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="312"/>
        <source>Signal strength</source>
        <translation>Độ mạnh tín hiệu</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="317"/>
        <source>Noise level</source>
        <translation>Mức độ nhiễu</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="323"/>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="328"/>
        <source>Bandwidth</source>
        <translation>Độ rộng đường truyền</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="333"/>
        <source>RX packets</source>
        <translation>Packets nhận</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="338"/>
        <source>RX bytes</source>
        <translation>Bytes nhận</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="343"/>
        <source>RX errors</source>
        <translation>Lỗi nhận</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="348"/>
        <source>RX dropped</source>
        <translation>Được bỏ qua nhận</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="353"/>
        <source>RX overruns</source>
        <translation>Tràn nhận</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="358"/>
        <source>RX frame</source>
        <translation>Khung nhận</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="363"/>
        <source>TX packets</source>
        <translation>Packets gửi</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="368"/>
        <source>TX bytes</source>
        <translation>Bytes gửi</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="373"/>
        <source>TX errors</source>
        <translation>Lỗi gửi</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="383"/>
        <source>TX overruns</source>
        <translation>Tràn gửi</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="388"/>
        <source>TX carrier</source>
        <translation>Truyền載器</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="267"/>
        <location filename="../gui/netif_summary_view_widget.h" line="269"/>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="282"/>
        <location filename="../gui/netif_summary_view_widget.h" line="284"/>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="378"/>
        <source>TX dropped</source>
        <translation>Được bỏ qua gửi</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="143"/>
        <source>Command line</source>
        <translation>Dòng lệnh</translation>
    </message>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="148"/>
        <source>Start time</source>
        <translation>Thời gian bắt đầu</translation>
    </message>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="138"/>
        <source>Name</source>
        <translation>Tên</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <location filename="../gui/xwin_kill_preview_background_widget.cpp" line="152"/>
        <source>Click the application you want to end</source>
        <translation>Nhấn vào ứng dụng bạn muốn kết thúc</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="183"/>
        <location filename="../gui/mem_detail_view_widget.cpp" line="25"/>
        <location filename="../gui/mem_stat_view_widget.cpp" line="107"/>
        <location filename="../memory_monitor.cpp" line="177"/>
        <source>Memory</source>
        <translation>Bộ nhớ</translation>
    </message>
    <message>
        <location filename="../gui/netif_item_view_widget.cpp" line="95"/>
        <location filename="../gui/netif_item_view_widget.cpp" line="121"/>
        <source>Receive</source>
        <translation>Nhận</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <location filename="../compact_cpu_monitor.cpp" line="233"/>
        <location filename="../cpu_monitor.cpp" line="233"/>
        <location filename="../cpu_monitor.cpp" line="242"/>
        <location filename="../gui/cpu_detail_widget.cpp" line="371"/>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="182"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../compact_disk_monitor.cpp" line="153"/>
        <source>Disk read</source>
        <translation>Đọc đĩa</translation>
    </message>
    <message>
        <location filename="../compact_disk_monitor.cpp" line="154"/>
        <source>Disk write</source>
        <translation>Viết đĩa</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="191"/>
        <location filename="../memory_monitor.cpp" line="203"/>
        <source>Memory</source>
        <translation>Bộ nhớ</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="203"/>
        <location filename="../compact_memory_monitor.cpp" line="210"/>
        <location filename="../gui/mem_stat_view_widget.cpp" line="115"/>
        <location filename="../memory_monitor.cpp" line="214"/>
        <location filename="../memory_monitor.cpp" line="221"/>
        <source>Swap</source>
        <translation>Hoán đổi</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="204"/>
        <location filename="../memory_monitor.cpp" line="215"/>
        <source>Not enabled</source>
        <translation>Không kích hoạt</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="158"/>
        <location filename="../network_monitor.cpp" line="216"/>
        <source>Download</source>
        <translation>Tải về</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="163"/>
        <location filename="../network_monitor.cpp" line="221"/>
        <source>Upload</source>
        <translation>Tải lên</translation>
    </message>
    <message>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="184"/>
        <location filename="../gui/netif_detail_view_widget.cpp" line="28"/>
        <location filename="../network_monitor.cpp" line="198"/>
        <source>Network</source>
        <translation>Mạng</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="160"/>
        <location filename="../network_monitor.cpp" line="218"/>
        <source>Total Received</source>
        <translation>Tổng đã nhận</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="165"/>
        <location filename="../network_monitor.cpp" line="223"/>
        <source>Total Sent</source>
        <translation>Tổng đã gửi</translation>
    </message>
    <message>
        <location filename="../gui/netif_item_view_widget.cpp" line="104"/>
        <location filename="../gui/netif_item_view_widget.cpp" line="130"/>
        <source>Send</source>
        <translation>Gửi</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_detail_view_widget.cpp" line="21"/>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="185"/>
        <source>Disks</source>
        <translation>Ổ đĩa</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="67"/>
        <source>Loading</source>
        <translation>Đang tải</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="633"/>
        <location filename="../process/process.cpp" line="55"/>
        <source>Very high</source>
        <translation>Rất cao</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="641"/>
        <location filename="../process/process.cpp" line="56"/>
        <source>High</source>
        <translation>Cao</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="649"/>
        <location filename="../process/process.cpp" line="57"/>
        <source>Normal</source>
        <translation>Bình thường</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="657"/>
        <location filename="../process/process.cpp" line="58"/>
        <source>Low</source>
        <translation>Thấp</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="665"/>
        <location filename="../process/process.cpp" line="59"/>
        <source>Very low</source>
        <translation>Rất thấp</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="673"/>
        <location filename="../process/process.cpp" line="60"/>
        <source>Custom</source>
        <translation>Tùy chỉnh</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="61"/>
        <source>Invalid</source>
        <translation>Không hợp lệ</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="199"/>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Lỗi: [%2] %3</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="156"/>
        <location filename="../process/process_db.cpp" line="196"/>
        <source>Failed to change process priority</source>
        <translation>Không thể thay đổi ưu tiên quá trình</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="61"/>
        <source>Applications</source>
        <translation>Ứng dụng</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="63"/>
        <source>My processes</source>
        <translation>Quá trình của tôi</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="65"/>
        <source>All processes</source>
        <translation>Tất cả quá trình</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <location filename="../process/process_db.cpp" line="267"/>
        <source>Failed to pause process</source>
        <translation>Không thể tạm dừng quá trình</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="270"/>
        <source>Failed to resume process</source>
        <translation>Không thể tiếp tục quá trình</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="273"/>
        <source>Failed to kill process</source>
        <translation>Không thể kết thúc quá trình</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="276"/>
        <source>Unknown error</source>
        <translation>Lỗi không xác định</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="337"/>
        <source>Failed in sending signal to process</source>
        <translation>Fehler beim Senden des Signals an den Prozess</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="264"/>
        <source>Failed to end process</source>
        <translation>Không thể kết thúc quá trình</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="58"/>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 ứng dụng và %2 quá trình đang chạy</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <location filename="../model/process_table_model.cpp" line="269"/>
        <source>No response</source>
        <translation>Không có phản hồi</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.cpp" line="275"/>
        <source>Suspend</source>
        <translation>Dừng lại</translation>
    </message>
    <message>
        <location filename="../process/process_name.cpp" line="90"/>
        <location filename="../process/process_name.cpp" line="99"/>
        <location filename="../process/process_name.cpp" line="104"/>
        <source>Tray</source>
        <translation>Khu vực hệ thống</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="680"/>
        <source>View command location</source>
        <translation>Xem vị trí lệnh</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="83"/>
        <location filename="../gui/process_table_view.cpp" line="684"/>
        <source>Properties</source>
        <translation>Tính năng</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="66"/>
        <location filename="../gui/process_table_view.cpp" line="608"/>
        <source>End process</source>
        <translation>Kết thúc quá trình</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="78"/>
        <location filename="../gui/process_table_view.cpp" line="620"/>
        <source>Resume process</source>
        <translation>Tiếp tục quá trình</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="89"/>
        <location filename="../gui/process_table_view.cpp" line="691"/>
        <source>Kill process</source>
        <translation>Killing quá trình</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="627"/>
        <source>Change priority</source>
        <translation>Thay đổi ưu tiên</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="72"/>
        <location filename="../gui/process_table_view.cpp" line="614"/>
        <source>Suspend process</source>
        <translation>Dừng lại quá trình</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1052"/>
        <source>Custom Priority</source>
        <translation>Ưu tiên tùy chỉnh</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1085"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Huỷ bỏ</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1087"/>
        <source>Change</source>
        <comment>button</comment>
        <translation>Thay đổi</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <location filename="../model/process_table_model.h" line="16"/>
        <source>Name</source>
        <translation>Tên</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="18"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="22"/>
        <source>Memory</source>
        <translation>Bộ nhớ</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="32"/>
        <source>Disk write</source>
        <translation>Ghi đĩa</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="30"/>
        <source>Disk read</source>
        <translation>Đọc đĩa</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="28"/>
        <source>Download</source>
        <translation>Tải xuống</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="26"/>
        <source>Upload</source>
        <translation>Tải lên</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="34"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="20"/>
        <source>User</source>
        <translation>Người dùng</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="36"/>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="38"/>
        <source>Priority</source>
        <translation>Ưu tiên</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="23"/>
        <source>Shared memory</source>
        <translation>Bộ nhớ chia sẻ</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="24"/>
        <source>Virtual memory</source>
        <translation>Bộ nhớ ảo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../system/cpu_set.cpp" line="426"/>
        <source>Not support</source>
        <translation>Không hỗ trợ</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="10"/>
        <source>Settings</source>
        <translation type="unfinished">Cài đặt</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="11"/>
        <source>System Protection</source>
        <translation>Bảo vệ hệ thống</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="12"/>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>Hiển thị cảnh báo khi sử dụng vượt ngưỡng</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="13"/>
        <source>CPU warning threshold (%)</source>
        <translation>Ngưỡng cảnh báo CPU (%)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="14"/>
        <source>Memory warning threshold (%)</source>
        <translation>Ngưỡng cảnh báo bộ nhớ (%)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="15"/>
        <source>Warning interval (min)</source>
        <translation>Khoảng thời gian cảnh báo (phút)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="16"/>
        <source>Notifications</source>
        <translation>Thông báo</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <location filename="../service/service_manager.cpp" line="342"/>
        <source>Failed to set service startup type</source>
        <translation>Không thể thiết lập loại khởi động dịch vụ</translation>
    </message>
    <message>
        <location filename="../service/service_manager.cpp" line="408"/>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Lỗi: Không thể thiết lập loại khởi động dịch vụ do quá trình con bị hỏng.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="157"/>
        <location filename="../gui/system_service_table_view.cpp" line="224"/>
        <location filename="../gui/system_service_table_view.cpp" line="292"/>
        <source>Service instance name</source>
        <translation>Tên thực thể dịch vụ</translation>
    </message>
    <message>
        <location filename="../gui/service_name_sub_input_dialog.cpp" line="38"/>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <location filename="../gui/service_name_sub_input_dialog.cpp" line="39"/>
        <source>Cancel</source>
        <translation>Hủy bỏ</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="118"/>
        <location filename="../gui/system_service_table_view.cpp" line="562"/>
        <source>Refresh</source>
        <translation>Làm mới</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="103"/>
        <location filename="../gui/system_service_table_view.cpp" line="542"/>
        <source>Start</source>
        <translation>Bắt đầu</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="108"/>
        <location filename="../gui/system_service_table_view.cpp" line="547"/>
        <source>Stop</source>
        <translation>Dừng</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="113"/>
        <location filename="../gui/system_service_table_view.cpp" line="552"/>
        <source>Restart</source>
        <translation>Khởi động lại</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="558"/>
        <source>Auto</source>
        <translation type="unfinished">Tự động</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="559"/>
        <source>Manual</source>
        <translation type="unfinished">Tay</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="557"/>
        <source>Startup type</source>
        <translation>Loại khởi động</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <location filename="../model/system_service_table_model.h" line="16"/>
        <source>Name</source>
        <translation>Tên</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="18"/>
        <source>Load</source>
        <translation>Tải</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="23"/>
        <source>Sub</source>
        <translation>Phụ</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="30"/>
        <source>Description</source>
        <translation>Mô tả</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="32"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="27"/>
        <source>Startup Type</source>
        <translation>Loại khởi động</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="21"/>
        <source>Start State</source>
        <translation>Trạng thái khởi động</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="25"/>
        <source>Start Tactic</source>
        <translation>Phương thức khởi động</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="132"/>
        <source>Settings</source>
        <translation>Cài đặt</translation>
    </message>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="165"/>
        <source>(Modifiable)</source>
        <translation>(Thay đổi được</translation>
    </message>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="278"/>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="387"/>
        <source>Range: %1-%2</source>
        <translation>Khoảng: %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="59"/>
        <location filename="../gui/main_window.cpp" line="129"/>
        <source>Force end application</source>
        <translation>Kết thúc ứng dụng</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="147"/>
        <source>Expand</source>
        <translation>Mở rộng</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="150"/>
        <source>Compact</source>
        <translation>Tightly packed</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="142"/>
        <source>View</source>
        <translation>Xem</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <location filename="../common/common.cpp" line="44"/>
        <location filename="../gui/toolbar.cpp" line="95"/>
        <source>Search</source>
        <translation>Tìm kiếm</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <location filename="../common/common.cpp" line="53"/>
        <location filename="../gui/main_window.cpp" line="224"/>
        <location filename="../gui/main_window.cpp" line="235"/>
        <location filename="../gui/toolbar.cpp" line="45"/>
        <source>Processes</source>
        <translation>Quá trình</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="98"/>
        <location filename="../gui/main_window.cpp" line="224"/>
        <location filename="../gui/main_window.cpp" line="235"/>
        <location filename="../gui/main_window.cpp" line="245"/>
        <location filename="../gui/toolbar.cpp" line="53"/>
        <source>Services</source>
        <translation>Dịch vụ</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="245"/>
        <location filename="../gui/toolbar.cpp" line="60"/>
        <source>Users</source>
        <translation>Người dùng</translation>
    </message>
</context>
<context>
    <name>User.Account.Operation</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="102"/>
        <source>Edit account information</source>
        <translation>Sửa thông tin tài khoản</translation>
    </message>
</context>
<context>
    <name>User.Account.Type</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="152"/>
        <source>Administrator</source>
        <translation>Quản trị viên</translation>
    </message>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="152"/>
        <source>Standard User</source>
        <translation>Người dùng tiêu chuẩn</translation>
    </message>
</context>
</TS>
